summaryrefslogtreecommitdiffstats
path: root/chromeos/dbus/nfc_record_client.h
diff options
context:
space:
mode:
authorarmansito@chromium.org <armansito@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-01-18 08:47:17 +0000
committerarmansito@chromium.org <armansito@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-01-18 08:47:17 +0000
commit20e38b8e9730ae28f077269d67e75a231bea7ca3 (patch)
tree24416175bfded4f8df6d13d99c8713df9caea7d3 /chromeos/dbus/nfc_record_client.h
parentb826fa8f5432ba0e02306d9901aa584653130e0d (diff)
downloadchromium_src-20e38b8e9730ae28f077269d67e75a231bea7ca3.zip
chromium_src-20e38b8e9730ae28f077269d67e75a231bea7ca3.tar.gz
chromium_src-20e38b8e9730ae28f077269d67e75a231bea7ca3.tar.bz2
nfc: Implement device::NfcTagChromeOS.
Implemented device::NfcTag for the Chrome OS platform. With this patch, Chrome can now interact with remote NFC tags. BUG=316471 TEST=device_unittests Review URL: https://codereview.chromium.org/116143009 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@245753 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chromeos/dbus/nfc_record_client.h')
-rw-r--r--chromeos/dbus/nfc_record_client.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/chromeos/dbus/nfc_record_client.h b/chromeos/dbus/nfc_record_client.h
index 84e2ef9..37a277e 100644
--- a/chromeos/dbus/nfc_record_client.h
+++ b/chromeos/dbus/nfc_record_client.h
@@ -96,8 +96,9 @@ class CHROMEOS_EXPORT NfcRecordClient : public DBusClient {
// have been received. This method will be called after
// Observer::RecordPropertyChanged has been called for all properties that
// were received through the initial property fetch that is done when the
// object proxy is first created. Observers can use this method to be
// notified when all existing properties of a record are available for use.
virtual void RecordPropertiesReceived(
const dbus::ObjectPath& object_path) {}
};
@@ -115,6 +116,11 @@ class CHROMEOS_EXPORT NfcRecordClient : public DBusClient {
virtual std::vector<dbus::ObjectPath> GetRecordsForDevice(
const dbus::ObjectPath& device_path) = 0;
+ // Returns the list of record object paths associated with the given tag
+ // identified by the D-Bus object path |tag_path|.
+ virtual std::vector<dbus::ObjectPath> GetRecordsForTag(
+ const dbus::ObjectPath& tag_path) = 0;
+
// Obtain the properties for the NFC record with object path |object_path|;
// any values should be copied if needed.
virtual Properties* GetProperties(const dbus::ObjectPath& object_path) = 0;
@@ -96,8 +96,9 @@ class CHROMEOS_EXPORT NfcRecordClient : public DBusClient {
// Observer::RecordPropertyChanged has been called for all properties that
// were received through the initial property fetch that is done when the
- // object proxy is first created. Observers can use this method to be
- // notified when all existing properties of a record are available for use.
+ // object proxy is first created or after a call to
+ // dbus::PropertySet::GetAll Observers can use this method to be notified
+ // when all existing properties of a record are available for use.
virtual void RecordPropertiesReceived(
const dbus::ObjectPath& object_path) {}